#[unsafe(no_mangle)]pub extern "C" fn tts_destroy(ctx: *mut tts_ctx)Expand description
Destroy a TTS context and free all associated resources.
Safety
ctx must be a pointer previously returned by tts_create,
or null (no-op).
#[unsafe(no_mangle)]pub extern "C" fn tts_destroy(ctx: *mut tts_ctx)Destroy a TTS context and free all associated resources.
ctx must be a pointer previously returned by tts_create,
or null (no-op).